<section id="community" class="py-24 bg-gray-50">
  <div class="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-20" data-aos="fade-up">
      <span class="inline-block text-xs uppercase tracking-widest text-gray-500 mb-3">
        {{ sections.community.title }}
      </span>
      <h2 class="text-3xl sm:text-4xl font-light text-gray-900 mb-4">
        {{ sections.community.subtitle }}
      </h2>
      <div class="w-16 h-px bg-gray-300 mx-auto mb-6"></div>
    </div>
    
    {% if sections.community.stats %}
    <div class="grid grid-cols-2 md:grid-cols-4 gap-8 mb-16">
      {% for stat in sections.community.stats %}
      <div class="text-center p-6 bg-white border border-gray-100 hover:shadow-sm transition-shadow duration-300" data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        <div class="text-3xl font-light text-gray-900 mb-3">{{ stat.value }}</div>
        <div class="w-8 h-px bg-gray-300 mx-auto mb-3"></div>
        <div class="text-sm text-gray-600 font-light uppercase tracking-wide">{{ stat.label }}</div>
      </div>
      {% endfor %}
    </div>
    {% endif %}
    
    {% if sections.community.highlights %}
    <div class="grid md:grid-cols-3 gap-8 mb-16">
      {% for highlight in sections.community.highlights %}
      <div class="bg-white p-8 border border-gray-100 hover:shadow-sm transition-shadow duration-300" data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        <h3 class="text-xl font-light text-gray-900 mb-4">{{ highlight.title }}</h3>
        <div class="w-8 h-px bg-gray-300 mb-4"></div>
        <p class="text-gray-600 font-light leading-relaxed mb-4">{{ highlight.description }}</p>
        <div class="text-sm text-gray-500 font-light">{{ highlight.members }} members</div>
      </div>
      {% endfor %}
    </div>
    {% endif %}
    
    {% if sections.community.cta %}
    <div class="text-center" data-aos="fade-up">
      <a href="{{ sections.community.cta.url }}" 
         class="inline-block px-8 py-3 border border-gray-900 text-gray-900 text-sm font-light tracking-widest uppercase hover:bg-gray-900 hover:text-white transition-colors duration-300">
        {{ sections.community.cta.label }}
      </a>
    </div>
    {% endif %}
  </div>
</section>