<section id="features" class="py-24 bg-white">
  <div class="max-w-4xl mx-auto px-4">
    <h2 class="text-4xl font-light text-gray-900 text-center mb-16" data-aos="fade-up">
      {{ sections.features.title }}
    </h2>
    
    <div class="grid md:grid-cols-3 gap-12">
      {% for feature in sections.features.items %}
      <div class="text-center" data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        <h3 class="text-xl font-medium text-gray-900 mb-4">
          {{ feature.title }}
        </h3>
        <p class="text-gray-600">
          {{ feature.subtitle }}
        </p>
      </div>
      {% endfor %}
    </div>
  </div>
</section>