<section id="stats" class="py-16 bg-primary text-white">
  <div class="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="grid md:grid-cols-2 lg:grid-cols-4 gap-8">
      {% for stat in sections.stats.items %}
      <div class="text-center" data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        <div class="w-16 h-16 bg-white/20 rounded-full flex items-center justify-center mx-auto mb-4">
          <i class="{{ stat.icon }} text-white text-2xl"></i>
        </div>
        <div class="text-3xl font-bold text-white mb-2">{{ stat.value }}</div>
        <div class="text-white/90 font-medium">{{ stat.label }}</div>
        {% if stat.description %}
        <p class="text-sm text-white/70 mt-1">{{ stat.description }}</p>
        {% endif %}
      </div>
      {% endfor %}
    </div>
  </div>
</section>