<section id="testimonials" class="h-screen w-full bg-gray-50 flex items-center">
  <div class="max-w-4xl mx-auto px-4">
    <h2 class="text-4xl font-light text-gray-900 text-center mb-16" data-aos="fade-up">
      {{ sections.testimonials.title }}
    </h2>
    
    {% if sections.testimonials.featured %}
    <div class="text-center mb-16" data-aos="fade-up">
      <blockquote class="text-2xl font-light text-gray-900 mb-8">
        "{{ sections.testimonials.featured.quote }}"
      </blockquote>
      <div class="text-gray-600">
        {{ sections.testimonials.featured.name }}, {{ sections.testimonials.featured.title }}
      </div>
    </div>
    {% endif %}
    
    <div class="grid md:grid-cols-2 gap-12">
      {% for testimonial in sections.testimonials.items %}
      <div data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        <blockquote class="text-lg text-gray-700 mb-4">
          "{{ testimonial.quote }}"
        </blockquote>
        <div class="text-sm text-gray-600">
          {{ testimonial.name }}
        </div>
      </div>
      {% endfor %}
    </div>
  </div>
</section>