<section id="cta" class="py-24 bg-gray-900 text-white">
  <div class="max-w-4xl mx-auto px-4 text-center">
    <h2 class="text-4xl font-light text-white mb-8" data-aos="fade-up">
      {{ sections.cta.title }}
    </h2>
    
    <p class="text-xl text-gray-300 mb-12 max-w-2xl mx-auto" data-aos="fade-up" data-aos-delay="100">
      {{ sections.cta.description }}
    </p>
    
    {% if sections.cta.buttons %}
    <div class="space-x-4" data-aos="fade-up" data-aos-delay="200">
      {% for button in sections.cta.buttons %}
      <a href="{{ button.url }}" 
         class="bg-white text-gray-900 px-8 py-3 text-sm font-medium hover:opacity-80 transition-opacity">
        {{ button.label }}
      </a>
      {% endfor %}
    </div>
    {% endif %}
  </div>
</section>