<section id="stats" class="py-24 bg-gradient-to-br from-primary to-secondary text-white relative overflow-hidden">
  <div class="absolute inset-0 bg-black/20"></div>
  <div class="absolute inset-0 bg-gradient-to-r from-transparent via-white/10 to-transparent"></div>
  
  <div class="relative max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-20" data-aos="zoom-in">
      <h2 class="text-5xl md:text-6xl font-black text-white mb-6">
        {{ sections.stats.title }}
      </h2>
      {% if sections.stats.subtitle %}
      <p class="text-xl text-white/90 max-w-4xl mx-auto">
        {{ sections.stats.subtitle }}
      </p>
      {% endif %}
      <div class="w-32 h-2 bg-white/30 rounded-full mx-auto mt-8"></div>
    </div>
    
    <div class="grid md:grid-cols-2 lg:grid-cols-4 gap-8">
      {% for stat in sections.stats.items %}
      <div class="group text-center" data-aos="zoom-in" data-aos-delay="{{ loop.index0 * 100 }}">
        <div class="bg-white/10 backdrop-blur-lg p-10 rounded-3xl border border-white/20 shadow-2xl transform group-hover:scale-110 group-hover:bg-white/20 transition-all duration-500">
          <div class="w-20 h-20 bg-white/20 backdrop-blur-sm rounded-2xl flex items-center justify-center mx-auto mb-8 group-hover:rotate-12 transition-transform duration-500">
            <i class="{{ stat.icon | default('ri-bar-chart-line') }} text-white text-2xl"></i>
          </div>
          
          <div class="text-5xl md:text-6xl font-black text-white mb-4 group-hover:scale-110 transition-transform duration-300">
            {{ stat.value }}
          </div>
          
          <div class="text-lg font-bold text-white/90 mb-2">{{ stat.label }}</div>
          
          {% if stat.description %}
          <p class="text-sm text-white/70">{{ stat.description }}</p>
          {% endif %}
        </div>
      </div>
      {% endfor %}
    </div>
  </div>
</section>