<section id="product_grid" class="py-24 bg-gray-50">
  <div class="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-20" data-aos="fade-up">
      <span class="inline-block text-xs uppercase tracking-widest text-gray-500 mb-3">
        {{ sections.product_grid.title }}
      </span>
      <h2 class="text-3xl sm:text-4xl font-light text-gray-900 mb-4">
        {{ sections.product_grid.subheading }}
      </h2>
      <div class="w-16 h-px bg-gray-300 mx-auto mb-6"></div>
    </div>
    
    <div class="grid md:grid-cols-2 lg:grid-cols-3 gap-8">
      {% for item in sections.product_grid.items %}
      <div class="bg-white border border-gray-100 overflow-hidden hover:shadow-sm transition-shadow duration-300" data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        {% if item.image %}
        <div class="aspect-[4/3] overflow-hidden">
          <img src="{{ item.image.src }}" 
               alt="{{ item.image.alt }}" 
               class="w-full h-full object-cover"
               loading="lazy">
        </div>
        {% endif %}
        
        <div class="p-8">
          <h3 class="text-xl font-light text-gray-900 mb-3">{{ item.name }}</h3>
          <div class="w-8 h-px bg-gray-300 mb-4"></div>
          <p class="text-gray-600 font-light mb-6 leading-relaxed">{{ item.description }}</p>
          
          {% if item.price %}
          <div class="flex items-center justify-between mb-6">
            <span class="text-2xl font-light text-gray-900">
              ${{ item.price.amount }}
            </span>
          </div>
          {% endif %}
          
          {% if item.offer and item.offer.description %}
          <p class="text-sm text-gray-500 font-light mb-6 bg-gray-50 p-3 border border-gray-100">
            {{ item.offer.description }}
          </p>
          {% endif %}
          
          <button class="w-full border border-gray-900 text-gray-900 py-3 text-sm font-light tracking-widest uppercase hover:bg-gray-900 hover:text-white transition-colors duration-300">
            Add to Cart
          </button>
        </div>
      </div>
      {% endfor %}
    </div>
  </div>
</section>